@@ -663,14 +663,14 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
         warning("Forcing dualstack")
         data['dualstack'] = True
     http_proxy = os.environ.get('HTTP_PROXY') or os.environ.get('http_proxy')
-    if 'http_proxy' not in data and http_proxy is not None:
+    if data['http_proxy'] is None and http_proxy is not None:
         pprint("Using proxy settings from environment")
         data['http_proxy'] = http_proxy
         https_proxy = os.environ.get('HTTPS_PROXY') or os.environ.get('https_proxy')
-        if 'https_proxy' not in data and https_proxy is not None:
+        if data['https_proxy'] is None and https_proxy is not None:
             data['https_proxy'] = https_proxy
         no_proxy = os.environ.get('NO_PROXY') or os.environ.get('no_proxy')
-        if 'no_proxy' not in data and no_proxy is not None:
+        if data['no_proxy'] is None and no_proxy is not None:
             data['no_proxy'] = no_proxy
     if data['ctlplanes'] == 1 and data['workers'] == 0\
        and 'ctlplane_memory' not in overrides and 'memory' not in overrides:
@@ -769,6 +769,9 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
     virtualization_nightly = data['virtualization_nightly']
     version = data['version']
     tag = data['tag']
+    if isinstance(tag, float) and str(tag).count('.') == 1 and len(str(tag).split('.')[1]) == 1:
+        tag = f'{tag}0'
+        data['tag'] = tag
     version = overrides.get('version') or detect_openshift_version(tag, OPENSHIFT_TAG)
     data['version'] = version
     if os.path.exists('coreos-installer'):
@@ -838,7 +841,7 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
         data['ipv6'] = True
         overrides['ipv6'] = True
         data['disconnected_ipv6_network'] = True
-        if not disconnected_vm and disconnected_url is None:
+        if not disconnected_vm and disconnected_url is None and data['http_proxy'] is None:
             warning("Forcing disconnected_vm to True as no disconnected_url was provided")
             data['disconnected_vm'] = True
             disconnected_vm = True
@@ -1341,12 +1344,14 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
         with open(f"{clusterdir}/openshift/99-kubevirt-fix-worker.yaml", 'w') as _f:
             _f.write(kubevirtworker)
     if sno:
-        sno_name = f"{cluster}-sno"
         sno_files = []
         sno_disable_nics = data['sno_disable_nics']
         if ipv6 or sno_disable_nics:
             nm_data = config.process_inputfile(cluster, f"{plandir}/kcli-ipv6.conf.j2", overrides=data)
             sno_files.append({'path': "/etc/NetworkManager/conf.d/kcli-ipv6.conf", 'data': nm_data})
+        sno_hostname = data['sno_hostname']
+        if sno_hostname is None:
+            sno_files.append({'path': "/etc/hostname", 'data': sno_hostname})
         sno_dns = data['sno_dns']
         if sno_dns is None:
             sno_dns = False
@@ -1403,7 +1408,7 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
         disable_ipv6 = 'ipv6' in overrides and not overrides['ipv6']
         data['disable_ipv6'] = disable_ipv6
         overrides['disable_ipv6'] = disable_ipv6
-        move(f"{clusterdir}/bootstrap-in-place-for-live-iso.ign", f"./{sno_name}.ign")
+        move(f"{clusterdir}/bootstrap-in-place-for-live-iso.ign", f"{cluster}-sno.ign")
         with open("iso.ign", 'w') as f:
             iso_overrides = data.copy()
             iso_overrides['image'] = 'rhcos4000'
@@ -1426,7 +1431,7 @@ def create(config, plandir, cluster, overrides, dnsconfig=None):
                 else:
                     sno_extra_args = bootstrap_data
                 iso_overrides['sno_extra_args'] = sno_extra_args
-            result = config.create_vm(sno_name, overrides=iso_overrides, onlyassets=True)
+            result = config.create_vm(f"{cluster}-sno", overrides=iso_overrides, onlyassets=True)
             pprint("Writing iso.ign to current dir")
             f.write(result['userdata'])
         live_url = os.environ.get('LIVEISO_URL') or overrides.get('liveiso_url')
