@@ -711,7 +711,7 @@ class Kubevirt():
         baseurl = baseurl.replace('https://', 'wss://')
         ws_url = f"{baseurl}/apis/subresources.{DOMAIN}/{VERSION}/namespaces/{namespace}/virtualmachineinstances/{name}"
         ws_url += "/vnc"
-        ws = create_connection(ws_url, sslopt={"context": context}, header=[f"{k}: {v}" for k, v in headers.items()])
+        ws = create_connection(ws_url, sslopt={"context": context}, header=headers)
         server = socket(AF_INET, SOCK_STREAM)
         localport = common.get_free_port()
         server.bind(("127.0.0.1", localport))
@@ -761,7 +761,7 @@ class Kubevirt():
         baseurl = baseurl.replace('https://', 'wss://')
         ws_url = f"{baseurl}/apis/subresources.{DOMAIN}/{VERSION}/namespaces/{namespace}/virtualmachineinstances/{name}"
         ws_url += "/console"
-        ws = create_connection(ws_url, sslopt={"context": context}, header=[f"{k}: {v}" for k, v in headers.items()])
+        ws = create_connection(ws_url, sslopt={"context": context}, header=headers)
         tty.setraw(sys.stdin.fileno())
         t1 = Thread(target=_console_read_from_ws, args=(ws,))
         t2 = Thread(target=_console_write_to_ws, args=(ws,))
